@@ -41,5 +41,13 @@ greedy <- function(A,nf,ns,etol=0,mattest=TRUE)
                   PACKAGE="edesign"
                   )
 
-    list(S=ans$S,det=ans$det)
+    ret <- list(S=ans$S,det=ans$det)
+    ret$A <- A
+    ret$na <- na
+    ret$nf <- nf
+    ret$ns <- ns
+    ret$ne <- ne
+    ret$method <- "greedy"
+    class(ret) <- "monet"
+    ret
   }
